<?php
// Include the database connection file
include '../../includes/connection.php';

// Check if the required data is sent via POST
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $email = $_POST['email'];
    $signal_type = $_POST['signal_type'];

    // Check if email and signal_type are provided
    if (empty($email) || empty($signal_type)) {
        echo json_encode(["status" => "error", "message" => "Email and signal type are required."]);
        exit();
    }

    // Check if the email exists in the database
    $sql = "SELECT * FROM Users WHERE email = ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("s", $email);
    $stmt->execute();
    $result = $stmt->get_result();
    
    if ($result->num_rows == 0) {
        echo json_encode(["status" => "error", "message" => "User not found."]);
        exit();
    }

    // Fetch user details
    $user = $result->fetch_assoc();
    
    // Check user status
    if ($user['user_status'] !== 'active') {
        echo json_encode(["status" => "error", "message" => "User banned by admin."]);
        exit();
    }

    // Determine the SQL query based on the signal type
    $query = "SELECT * FROM ActiveSignals WHERE 1=1";
    if ($signal_type === 'Free') {
        $query .= " AND SignalType = 'Free'";
    } elseif ($signal_type === 'Standard') {
        $query .= " AND (SignalType = 'Free' OR SignalType = 'Standard')";
    } elseif ($signal_type === 'Premium') {
        $query .= " AND (SignalType = 'Free' OR SignalType = 'Premium')";
    } elseif ($signal_type === 'Lifetime') {
        // No additional filter for Lifetime
    } else {
        echo json_encode(["status" => "error", "message" => "Invalid signal type."]);
        exit();
    }

    // Execute the query
    $result = $conn->query($query);

    if ($result->num_rows > 0) {
        $signals = [];
        while ($row = $result->fetch_assoc()) {
            $signals[] = $row;
        }
        echo json_encode(["status" => "success", "signals" => $signals]);
    } else {
        echo json_encode(["status" => "success", "message" => "No signals found."]);
    }

    // Close the statement and connection
    $stmt->close();
    $conn->close();
} else {
    echo json_encode(["status" => "error", "message" => "Invalid request method."]);
}
?>
