<?php
// Include the database connection file
include '../../includes/connection.php';

// Check if the required data is sent via POST
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $email = $_POST['email'];
    $signal_type = isset($_POST['signal_type']) ? strtolower(trim($_POST['signal_type'])) : ''; // Normalize signal_type to lowercase and trim spaces

    // Check if email is provided
    if (empty($email)) {
        echo json_encode(["status" => "error", "message" => "Email is required."]);
        exit();
    }

    // Check if the email exists and retrieve the user status
    $sql = "SELECT user_status FROM Users WHERE email = ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("s", $email);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows == 0) {
        echo json_encode(["status" => "error", "message" => "User not found."]);
    } else {
        $user = $result->fetch_assoc();
        if ($user['user_status'] != 'active') {
            echo json_encode(["status" => "error", "message" => "User banned by admin."]);
        } else {
            // Validate the signal_type
            if ($signal_type === 'expired') {
                // Fetch all expired signals
                $sql = "SELECT * FROM ExpiredSignals";
                $result = $conn->query($sql);

                if ($result->num_rows > 0) {
                    $signals = [];
                    while ($row = $result->fetch_assoc()) {
                        $signals[] = $row;
                    }
                    echo json_encode(["status" => "success", "signals" => $signals]);
                } else {
                    echo json_encode(["status" => "error", "message" => "No expired signals found."]);
                }
            } else {
                echo json_encode(["status" => "error", "message" => "Invalid signal type."]);
            }
        }
    }

    // Close the statement and connection
    $stmt->close();
    $conn->close();
} else {
    echo json_encode(["status" => "error", "message" => "Invalid request method."]);
}
?>
