<?php
// Include the database connection file
include '../../includes/connection.php';

// Check if the required data is sent via POST
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $email = $_POST['email'];

    // Check if email field is empty
    if (empty($email)) {
        echo json_encode(["status" => "error", "message" => "Email is required."]);
        exit();
    }

    // Check if email exists in the database
    $sql = "SELECT name, email, telegram_username, user_status FROM Users WHERE email = ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("s", $email);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows == 0) {
        echo json_encode(["status" => "error", "message" => "Email not registered."]);
    } else {
        $user = $result->fetch_assoc();
        // Check if the user status is active
        if ($user['user_status'] != 'active') {
            echo json_encode(["status" => "error", "message" => "Your account has been banned by the admin."]);
        } else {
            // Send success response with user details excluding password
            echo json_encode([
                "status" => "success",
                "data" => [
                    "name" => $user['name'],
                    "email" => $user['email'],
                    "telegram_username" => $user['telegram_username'],
                    "user_status" => $user['user_status']
                ]
            ]);
        }
    }

    // Close the statement and connection
    $stmt->close();
    $conn->close();
} else {
    echo json_encode(["status" => "error", "message" => "Invalid request method."]);
}
?>
