<?php
// Include the database connection file
include '../../includes/connection.php';

// Check if the required data is sent via POST
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $email = $_POST['email'];
    $password = $_POST['password'];

    // Check if any field is empty
    if (empty($email) || empty($password)) {
        echo json_encode(["status" => "error", "message" => "Email and password are required."]);
        exit();
    }

    // Check if email exists
    $sql = "SELECT * FROM Users WHERE email = ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("s", $email);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows === 0) {
        echo json_encode(["status" => "error", "message" => "Email not registered."]);
    } else {
        $user = $result->fetch_assoc();

        // Check user status
        if ($user['user_status'] !== 'active') {
            echo json_encode(["status" => "error", "message" => "User account is banned by admin. Please contact support."]);
        } else {
            // Verify password
            if (password_verify($password, $user['password'])) {
                echo json_encode(["status" => "success", "message" => "Login successful."]);
            } else {
                echo json_encode(["status" => "error", "message" => "Invalid password."]);
            }
        }
    }

    // Close the statement and connection
    $stmt->close();
    $conn->close();
} else {
    echo json_encode(["status" => "error", "message" => "Invalid request method."]);
}
?>
